@@ -26,20 +26,9 @@ from histdatacom.concurrency import get_pool_cpu_count
 from histdatacom.concurrency import ProcessPool
 from histdatacom.concurrency import InfluxDBWriter
 from histdatacom.api import _API
+from histdatacom import config
 
 class _Influx():
-    def __init__(self, args, records_current_, records_next_, csv_chunks_queue_):
-        self.args = args
-
-        global records_current
-        records_current = records_current_
-
-        global records_next
-        records_next = records_next_
-
-        global csv_chunks_queue
-        csv_chunks_queue = csv_chunks_queue_
-
     def init_counters(self, csv_chunks_queue_, records_current_, records_next_, args_):
         global csv_chunks_queue
         csv_chunks_queue = csv_chunks_queue_
@@ -136,7 +125,7 @@ class _Influx():
                                  initargs=(csv_chunks_queue,
                                            records_current,
                                            records_next,
-                                           self.args.copy())) as executor:
+                                           config.args)) as executor:
 
             data = rx.from_iterable(jay.to_tuples()) \
                 .pipe(ops.buffer_with_count(25_000),
@@ -162,7 +151,7 @@ class _Influx():
                                  initargs=(csv_chunks_queue,
                                            records_current,
                                            records_next,
-                                           self.args.copy())) as executor:
+                                           config.args)) as executor:
 
             fieldnames = self.fieldnames_match(record.data_format, record.data_timeframe)
             dialect = get_csv_dialect(csv_path)
@@ -183,34 +172,34 @@ class _Influx():
         record.status = "INFLUX_UPLOAD"
         record.write_info_file(base_dir=args['default_download_dir'])
 
-    def import_data(self, records_current, records_next, csv_chunks_queue):
+    def import_data(self):
 
-        writer = InfluxDBWriter(self.args, csv_chunks_queue)
+        writer = InfluxDBWriter(config.args, config.csv_chunks_queue)
         writer.start()
 
         pool = ProcessPool(self.import_file,
-                           self.args,
+                           config.args,
                            "Adding", "CSVs to influx queue...",
-                           get_pool_cpu_count(self.args['cpu_utilization']) - 1\
-                                              if get_pool_cpu_count(self.args['cpu_utilization']) >= 2 \
+                           get_pool_cpu_count(config.args['cpu_utilization']) - 1\
+                                              if get_pool_cpu_count(config.args['cpu_utilization']) >= 2 \
                                               else 1,
                            join=False,
                            dump=False)
 
-        pool(records_current, records_next, csv_chunks_queue)
+        pool(config.current_queue, config.next_queue, config.csv_chunks_queue)
 
         with Progress(TextColumn(text_format="[cyan]...finishing upload to influxdb"),
                       SpinnerColumn(), SpinnerColumn(), SpinnerColumn(),
                       TimeElapsedColumn()) as progress:
             task_id = progress.add_task("waiting", total=0)
 
-            records_current.join()
-            csv_chunks_queue.put(None)
-            csv_chunks_queue.join()
+            config.current_queue.join()
+            config.csv_chunks_queue.put(None)
+            config.csv_chunks_queue.join()
             progress.advance(task_id, 0.75)
 
         print("[cyan] done.")
-        records_next.dump_to_queue(records_current)
+        config.next_queue.dump_to_queue(config.current_queue)
 
     @classmethod
     def load_influx_yaml(cls):
