@@ -12,7 +12,7 @@ from histdatacom.utils import create_full_path
 
 
 class Record:
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs) -> None:
         self.url = kwargs.get("url", "")
         self.status = kwargs.get("status", "")
         self.encoding = kwargs.get("encoding", "")
@@ -29,8 +29,7 @@ class Record:
         self.zip_filename = kwargs.get("zip_filename", "")
         self.csv_filename = kwargs.get("csv_filename", "")
         self.jay_filename = kwargs.get("jay_filename", "")
-        self.csv_linecount = kwargs.get("csv_linecount", "")
-        self.jay_linecount = kwargs.get("jay_linecount", "")
+        self.jay_line_count = kwargs.get("jay_line_count", "")
         self.jay_start = kwargs.get("jay_start", "")
         self.jay_end = kwargs.get("jay_end", "")
         self.zip_persist = kwargs.get("zip_persist", "")
@@ -78,10 +77,6 @@ class Record:
             self.data_dir = record_data_dir
             return self.data_dir
 
-    def set_csv_linecount(self):
-        with open(f"{self.data_dir}{self.csv_filename}") as csv:
-            self.csv_linecount = sum(1 for _ in csv)
-
     def create_record_data_dir(self, base_dir=""):
         try:
             if self.data_dir != "":
@@ -94,7 +89,7 @@ class Record:
             print(err)
             sys.exit()
 
-    def write_info_file(self, base_dir=""):
+    def write_info_file(self, base_dir: str="") -> None:
         try:
             if self.data_dir == "":
                 if base_dir != "":
@@ -113,7 +108,7 @@ class Record:
             print(err)
             sys.exit()
 
-    def delete_info_file(self):
+    def delete_info_file(self) -> None:
         if os.path.exists(f"{self.data_dir}.info"):
             os.remove(f"{self.data_dir}.info")
 
@@ -145,8 +140,7 @@ class Record:
                 'data_tk': self.data_tk,
                 'zip_filename': self.zip_filename,
                 'csv_filename': self.csv_filename,
-                'csv_linecount': self.csv_linecount,
-                'jay_linecount': self.jay_linecount,
+                'jay_line_count': self.jay_line_count,
                 'jay_start': self.jay_start,
                 'jay_end': self.jay_end,
                 'jay_filename': self.jay_filename,
