@@ -13,21 +13,13 @@ from histdatacom.fx_enums import get_valid_format_timeframes
 from histdatacom.records import Record
 from histdatacom.concurrency import get_pool_cpu_count
 from histdatacom.concurrency import ThreadPool
+from histdatacom import config
 
 
 class _URLs:
-    def __init__(self, args, records_current_, records_next_):
-        # setting relationship to global outer parent
-        self.args = args
-
-        global records_current
-        records_current = records_current_
-
-        global records_next
-        records_next = records_next_
-
-        self.args["base_url"] = 'http://www.histdata.com/download-free-forex-data/'
-        self.args["post_headers"] = {
+    def __init__(self):
+        config.args["base_url"] = 'http://www.histdata.com/download-free-forex-data/'
+        config.args["post_headers"] = {
             "Host": "www.histdata.com",
             "Connection": "keep-alive",
             "Content-Length": "101",
@@ -41,22 +33,22 @@ class _URLs:
             "Accept-Encoding": "gzip, deflate",
             "Accept-Language": "en-US,en;q=0.9"}
 
-    def populate_initial_queue(self, records_current, records_next):
-        for url in self.generate_form_urls(self.args["start_yearmonth"],
-                                           self.args["end_yearmonth"],
-                                           self.args['formats'],
-                                           self.args["pairs"],
-                                           self.args['timeframes'],
-                                           self.args["base_url"]):
+    def populate_initial_queue(self):
+        for url in self.generate_form_urls(config.args["start_yearmonth"],
+                                           config.args["end_yearmonth"],
+                                           config.args['formats'],
+                                           config.args["pairs"],
+                                           config.args['timeframes'],
+                                           config.args["base_url"]):
             record = Record()
             record(url=url, status="URL_NEW")
-            record.restore_momento(base_dir=self.args['default_download_dir'])
+            record.restore_momento(base_dir=config.args['default_download_dir'])
 
             if record.status != "URL_NO_REPO_DATA":
-                record.write_info_file(base_dir=self.args['default_download_dir'])
-                records_next.put(record)
+                record.write_info_file(base_dir=config.args['default_download_dir'])
+                config.next_queue.put(record)
 
-        records_next.dump_to_queue(records_current)
+        config.next_queue.dump_to_queue(config.current_queue)
 
     def validate_url(self, record, args):
         try:
@@ -70,7 +62,7 @@ class _URLs:
                 record.status = "URL_VALID"
                 record.write_info_file(base_dir=args['default_download_dir'])
 
-            records_next.put(record)
+            config.next_queue.put(record)
         except ValueError:
             print(f"Info: Histdata.com does not have: {record.url}")
             record.status = "URL_NO_REPO_DATA"
@@ -80,16 +72,16 @@ class _URLs:
             record.delete_info_file()
             raise
         finally:
-            records_current.task_done()
+            config.current_queue.task_done()
 
-    def validate_urls(self, records_current, records_next):
+    def validate_urls(self):
 
         pool = ThreadPool(self.validate_url,
-                          self.args,
+                          config.args,
                           "Validating", "URLs...",
-                          get_pool_cpu_count(self.args['cpu_utilization']) * 3)
+                          get_pool_cpu_count(config.args['cpu_utilization']) * 3)
 
-        pool(records_current, records_next)
+        pool(config.current_queue, config.next_queue)
 
     def download_zip(self, record, args):
         try:
@@ -99,14 +91,12 @@ class _URLs:
                          or os.path.exists(record.data_dir + record.csv_filename)
                          or os.path.exists(record.data_dir + record.jay_filename))
                 ):
-                res = self.request_file(record, args)
-                record.zip_filename = res.headers["Content-Disposition"].split(";")[1].split("=")[1]
-                self.write_file(record, res.content)
 
+                self.get_zip_file(record, args)
                 record.status = "CSV_ZIP" if record.status == "URL_VALID" else record.status
                 record.write_info_file(base_dir=args['default_download_dir'])
 
-            records_next.put(record)
+            config.next_queue.put(record)
         except KeyError:
             print(f"Invalid Zip on histdata.com: {record.url}", sys.exc_info())
             record.delete_info_file()
@@ -115,10 +105,10 @@ class _URLs:
             record.delete_info_file()
             raise
         finally:
-            records_current.task_done()
+            config.current_queue.task_done()
 
     @classmethod
-    def request_file(cls, record, args):
+    def request_file(cls, record: Record, args: dict) -> requests.Response:
         post_headers = args['post_headers'].copy()
         post_headers["Referer"] = record.url
         return requests.post("http://www.histdata.com/get.php",
@@ -131,19 +121,19 @@ class _URLs:
                              headers=post_headers)
 
     @classmethod
-    def write_file(cls, record, content):
+    def write_file(cls, record: Record, content: bytes) -> None:
         zip_path = record.data_dir + record.zip_filename
         with open(zip_path, "wb") as zip_file:
             zip_file.write(content)
 
-    def download_zips(self, records_current, records_next):
+    def download_zips(self):
 
         pool = ThreadPool(self.download_zip,
-                          self.args,
+                          config.args,
                           "Downloading", "ZIPs...",
-                          get_pool_cpu_count(self.args['cpu_utilization']) * 3)
+                          get_pool_cpu_count(config.args['cpu_utilization']) * 3)
 
-        pool(records_current, records_next)
+        pool(config.current_queue, config.next_queue)
 
     @classmethod
     def get_page_data(cls, url):
@@ -197,6 +187,19 @@ class _URLs:
             month = 1
         return month
 
+    @classmethod
+    def get_zip_file_name(cls, response: requests.Response) -> str:
+        zip_file_name: str = response.headers["Content-Disposition"]\
+            .split(";")[1]\
+            .split("=")[1]
+        return zip_file_name
+
+    @classmethod
+    def get_zip_file(cls, record: Record, args: dict) -> None:
+        res = cls.request_file(record, args)
+        record.zip_filename = cls.get_zip_file_name(res)
+        cls.write_file(record, res.content)
+
     @classmethod
     def generate_form_urls(cls,
                            start_yearmonth,
